#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Read HARPIA device config example.

Read and parse HARPIA device config XML file

This script is a part of the HARPIA Microscopy Kit, which is a set of tools for
the alignment, characterization and troubleshooting of the HARPIA-MM extension
of the HARPIA spectroscopy system.

support@lightcon.com
www.lightcon.com
All rights reserved.
© 2019-2024 Light Conversion
"""
import xml.etree.ElementTree as ET

file_name = "C:/Users/Public/Documents/Light Conversion/HARPIA Service App/Settings/deviceSettings.xml"
file_name = "test_data/deviceSettings.xml"

try:
    xml_data = ET.parse(file_name)
    for section in xml_data.getroot().findall('configSection'):
        if section.get('name') == 'Microscope':
            harpia_cam_sn = section.findall('lastUsedCameraSerialNumber')[0].text
            print(f"HARPIA camera SN {harpia_cam_sn}")
except Exception as excpt:
    print("Could not determine HARPIA camera SN")
    harpia_cam_sn = None



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Pump-probe XYZ overlap images using a sample plane camera.

Acquire pump and probe overlap images using a sample plane camera.

This script is a part of the HARPIA Microscopy Kit, which is a set of tools for
the alignment, characterization and troubleshooting of HARPIA-MM Microscopy
Extension.

Contact: lukas.kontenis@lightcon.com, support@lightcon.com

Copyright (c) 2019-2024 Light Conversion
All rights reserved.
www.lightcon.com
"""
from .dep_check import harpiamm_dep_check
harpiamm_dep_check()

from harpiamm.cam_focus_test import cam_focus_test

# Start and end pos are in mm. Camera to use can be specified either by SN or
# index (cam_id) in the list as reported by PySpin GetCameras(). Enumeration by
# SN often fails due to a bug in PySpin, and there is no easy way for the end
# user to find out camera IDs. However, cam_id is useful to simply select the
# "other" camera when the wrong camera is selected and the script does not run.
cam_focus_test(start_pos=-2, end_pos=2, num_steps=50, cam_id=None, cam_sn=None)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Pump-probe overlap analysis script.

Generate a pump-probe XYZ overlap report. The report contains three panels
which show the FWHM beam size and the focus X and Y position as a function of
the Z position.

Please specify the objective type and the device serial number

This script is a part of the HARPIA Microscopy Kit, which is a set of tools for
the alignment, characterization and troubleshooting of HARPIA-MM Microscopy
Extension.

Contact: lukas.kontenis@lightcon.com, support@lightcon.com

Copyright (c) 2019-2025 Light Conversion
All rights reserved.
www.lightcon.com
"""
from harpiamm.overlap_analysis import make_overlap_report

# make_overlap_report() will be called next to analyze the pump-probe overlap
# data and produce a report. If the obj_id and device_sn arguments are not set
# a dialog will be shown for user input. Typical arguments are:
#   obj_id='nikon_pf_10x'
#   device_sn="M00000"
# The following objective ids are supported: nikon_pf_4x, nikon_pf_10x
# The device serial number must be in the M00000 format
make_overlap_report(path="../test-data/HARPIA-MM Overlap test dataset - M24079 10x/", device_sn="M24079", obj_id='nikon_pf_10x')

input("Press any key to close this window")
